#!/usr/bin/env python
import pytest
from dios import *

import pandas as pd
import numpy as np
from copy import deepcopy
from pandas.tests.series.conftest import datetime_series

__author__ = "Bert Palm"
__email__ = "bert.palm@ufz.de"
__copyright__ = "Copyright 2018, Helmholtz-Zentrum für Umweltforschung GmbH - UFZ"


@pytest.fixture()
def dictofseries(datetime_series):
    dios = DictOfSeries()
    for i in range(5):
        dios[f'c{i}'] = datetime_series.copy() * (i+1) // 2
    return dios


def test_len__len__(datetime_series, maxlen=10):

    dios = DictOfSeries()
    assert len(dios) == 0

    for i in range(maxlen):
        dios[f'c{i}'] = datetime_series.copy()
        assert len(dios) == i + 1

    for i in reversed(range(maxlen)):
        assert len(dios) == i + 1
        del dios[f'c{i}']

    assert len(dios) == 0


def test_copy_copy_empty__copy__(dictofseries):
    dios = dictofseries.copy()
    shallow = dios.copy(deep=False)
    deep = dios.copy(deep=True)
    empty = dios.copy_empty()

    assert dios is not shallow
    assert dios is not deep
    assert dios is not empty

    assert dios.itype == shallow.itype
    assert dios.itype == deep.itype
    assert dios.itype == empty.itype

    for i in dios:
        assert dios[i].index is shallow[i].index
        assert dios[i].index is not deep[i].index
        dios[i][0] = 999999
        assert dios[i][0] == shallow[i][0]
        assert dios[i][0] != deep[i][0]


def test__mul__(dictofseries):
    a = dictofseries.copy()
    for i in [1,2,50, 33.3, 0.1, 0]:
        b = a * i
        for c in b:
            exp = a[c] * i
            assert np.all(b[c] == exp)
            assert b[c] is not exp


def test__eq__(dictofseries):
    a = dictofseries.copy()
    b = dictofseries.copy()

    assert a is not b
    assert (a == b).aaall()
    x = b['c0']
    x.iloc[5] = 5
    b['c0'] = x
    assert (a != b).aaany()
    # assert False


